==> kadaster-gds2-2.4-sources.jar: nl/kadaster/schemas/gds2/afgifte_bestandenlijstresultaat/afgifte/v20170401/AfgifteType.java <==

package nl.kadaster.schemas.gds2.afgifte_bestandenlijstresultaat.afgifte.v20170401;

import java.math.BigInteger;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.datatype.XMLGregorianCalendar;
import nl.kadaster.schemas.gds2.afgifte_bestandenlijstresultaat.bestand.v20170401.Bestand;
import nl.kadaster.schemas.gds2.afgifte_bestandenlijstresultaat.kenmerken.v20170401.BestandKenmerkenType;
import nl.logius.digikoppeling.gb._2010._10.ExternalDataReference;


/**
 * &lt;p&gt;Java class for AfgifteType complex type.
 * 
 * &lt;p&gt;The following schema fragment specifies the expected content contained within this class.
 * 
 * &lt;pre&gt;
 * &amp;lt;complexType name="AfgifteType"&amp;gt;
 *   &amp;lt;complexContent&amp;gt;
 *     &amp;lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&amp;gt;
 *       &amp;lt;sequence&amp;gt;
 *         &amp;lt;element name="afgifteID"&amp;gt;
 *           &amp;lt;simpleType&amp;gt;
 *             &amp;lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&amp;gt;
 *               &amp;lt;maxLength value="36"/&amp;gt;
 *             &amp;lt;/restriction&amp;gt;
 *           &amp;lt;/simpleType&amp;gt;
 *         &amp;lt;/element&amp;gt;
 *         &amp;lt;element name="klantAfgiftenummer" type="{http://www.w3.org/2001/XMLSchema}integer"/&amp;gt;
 *         &amp;lt;element name="afgiftereferentie" minOccurs="0"&amp;gt;
 *           &amp;lt;simpleType&amp;gt;
 *             &amp;lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&amp;gt;
 *               &amp;lt;minLength value="1"/&amp;gt;
 *               &amp;lt;maxLength value="1024"/&amp;gt;
 *             &amp;lt;/restriction&amp;gt;
 *           &amp;lt;/simpleType&amp;gt;
 *         &amp;lt;/element&amp;gt;
 *         &amp;lt;element name="contractAfgiftenummer" type="{http://www.w3.org/2001/XMLSchema}integer" minOccurs="0"/&amp;gt;
 *         &amp;lt;element ref="{http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstresultaat/bestand/v20170401}Bestand"/&amp;gt;
 *         &amp;lt;element name="beschikbaarTot" type="{http://www.w3.org/2001/XMLSchema}dateTime"/&amp;gt;
 *         &amp;lt;element ref="{http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstresultaat/kenmerken/v20170401}BestandKenmerken" minOccurs="0"/&amp;gt;
 *         &amp;lt;element ref="{http://www.logius.nl/digikoppeling/gb/2010/10}digikoppeling-external-datareferences"/&amp;gt;
 *       &amp;lt;/sequence&amp;gt;
 *     &amp;lt;/restriction&amp;gt;
 *   &amp;lt;/complexContent&amp;gt;
 * &amp;lt;/complexType&amp;gt;
 * &lt;/pre&gt;
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "AfgifteType", propOrder = {
    "afgifteID",
    "klantAfgiftenummer",
    "afgiftereferentie",
    "contractAfgiftenummer",
    "bestand",
    "beschikbaarTot",
    "bestandKenmerken",
    "digikoppelingExternalDatareferences"
})
public class AfgifteType {

    @XmlElement(required = true)
    protected String afgifteID;
    @XmlElement(required = true)
    protected BigInteger klantAfgiftenummer;
    protected String afgiftereferentie;
    protected BigInteger contractAfgiftenummer;
    @XmlElement(name = "Bestand", namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstresultaat/bestand/v20170401", required = true)
    protected Bestand bestand;
    @XmlElement(required = true)
    @XmlSchemaType(name = "dateTime")
    protected XMLGregorianCalendar beschikbaarTot;
    @XmlElement(name = "BestandKenmerken", namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstresultaat/kenmerken/v20170401")
    protected BestandKenmerkenType bestandKenmerken;
    @XmlElement(name = "digikoppeling-external-datareferences", namespace = "http://www.logius.nl/digikoppeling/gb/2010/10", required = true)
    protected ExternalDataReference digikoppelingExternalDatareferences;

    /**
     * Gets the value of the afgifteID property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAfgifteID() {
        return afgifteID;
    }

    /**
     * Sets the value of the afgifteID property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAfgifteID(String value) {
        this.afgifteID = value;
    }

    /**
     * Gets the value of the klantAfgiftenummer property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getKlantAfgiftenummer() {
        return klantAfgiftenummer;
    }

    /**
     * Sets the value of the klantAfgiftenummer property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setKlantAfgiftenummer(BigInteger value) {
        this.klantAfgiftenummer = value;
    }

    /**
     * Gets the value of the afgiftereferentie property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAfgiftereferentie() {
        return afgiftereferentie;
    }

    /**
     * Sets the value of the afgiftereferentie property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAfgiftereferentie(String value) {
        this.afgiftereferentie = value;
    }

    /**
     * Gets the value of the contractAfgiftenummer property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getContractAfgiftenummer() {
        return contractAfgiftenummer;
    }

    /**
     * Sets the value of the contractAfgiftenummer property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setContractAfgiftenummer(BigInteger value) {
        this.contractAfgiftenummer = value;
    }

    /**
     * Gets the value of the bestand property.
     * 
     * @return
     *     possible object is
     *     {@link Bestand }
     *     
     */
    public Bestand getBestand() {
        return bestand;
    }

    /**
     * Sets the value of the bestand property.
     * 
     * @param value
     *     allowed object is
     *     {@link Bestand }
     *     
     */
    public void setBestand(Bestand value) {
        this.bestand = value;
    }

    /**
     * Gets the value of the beschikbaarTot property.
     * 
     * @return
     *     possible object is
     *     {@link XMLGregorianCalendar }
     *     
     */
    public XMLGregorianCalendar getBeschikbaarTot() {
        return beschikbaarTot;
    }

    /**
     * Sets the value of the beschikbaarTot property.
     * 
     * @param value
     *     allowed object is
     *     {@link XMLGregorianCalendar }
     *     
     */
    public void setBeschikbaarTot(XMLGregorianCalendar value) {
        this.beschikbaarTot = value;
    }

    /**
     * Gets the value of the bestandKenmerken property.
     * 
     * @return
     *     possible object is
     *     {@link BestandKenmerkenType }
     *     
     */
    public BestandKenmerkenType getBestandKenmerken() {
        return bestandKenmerken;
    }

    /**
     * Sets the value of the bestandKenmerken property.
     * 
     * @param value
     *     allowed object is
     *     {@link BestandKenmerkenType }
     *     
     */
    public void setBestandKenmerken(BestandKenmerkenType value) {
        this.bestandKenmerken = value;
    }

    /**
     * Gets the value of the digikoppelingExternalDatareferences property.
     * 
     * @return
     *     possible object is
     *     {@link ExternalDataReference }
     *     
     */
    public ExternalDataReference getDigikoppelingExternalDatareferences() {
        return digikoppelingExternalDatareferences;
    }

    /**
     * Sets the value of the digikoppelingExternalDatareferences property.
     * 
     * @param value
     *     allowed object is
     *     {@link ExternalDataReference }
     *     
     */
    public void setDigikoppelingExternalDatareferences(ExternalDataReference value) {
        this.digikoppelingExternalDatareferences = value;
    }

}

==> kadaster-gds2-3.1-sources.jar: nl/kadaster/schemas/gds2/afgifte_bestandenlijstresultaat/afgifte/v20170401/AfgifteType.java <==

package nl.kadaster.schemas.gds2.afgifte_bestandenlijstresultaat.afgifte.v20170401;

import java.math.BigInteger;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.datatype.XMLGregorianCalendar;
import nl.kadaster.schemas.gds2.afgifte_bestandenlijstresultaat.bestand.v20170401.Bestand;
import nl.kadaster.schemas.gds2.afgifte_bestandenlijstresultaat.kenmerken.v20170401.BestandKenmerkenType;
import nl.logius.digikoppeling.gb._2010._10.ExternalDataReference;


/**
 * <p>Java class for AfgifteType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="AfgifteType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="afgifteID"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="36"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="klantAfgiftenummer" type="{http://www.w3.org/2001/XMLSchema}integer"/&gt;
 *         &lt;element name="afgiftereferentie" minOccurs="0"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;minLength value="1"/&gt;
 *               &lt;maxLength value="1024"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="contractAfgiftenummer" type="{http://www.w3.org/2001/XMLSchema}integer" minOccurs="0"/&gt;
 *         &lt;element ref="{http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstresultaat/bestand/v20170401}Bestand"/&gt;
 *         &lt;element name="beschikbaarTot" type="{http://www.w3.org/2001/XMLSchema}dateTime"/&gt;
 *         &lt;element ref="{http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstresultaat/kenmerken/v20170401}BestandKenmerken" minOccurs="0"/&gt;
 *         &lt;element ref="{http://www.logius.nl/digikoppeling/gb/2010/10}digikoppeling-external-datareferences"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "AfgifteType", propOrder = {
    "afgifteID",
    "klantAfgiftenummer",
    "afgiftereferentie",
    "contractAfgiftenummer",
    "bestand",
    "beschikbaarTot",
    "bestandKenmerken",
    "digikoppelingExternalDatareferences"
})
public class AfgifteType {

    @XmlElement(required = true)
    protected String afgifteID;
    @XmlElement(required = true)
    protected BigInteger klantAfgiftenummer;
    protected String afgiftereferentie;
    protected BigInteger contractAfgiftenummer;
    @XmlElement(name = "Bestand", namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstresultaat/bestand/v20170401", required = true)
    protected Bestand bestand;
    @XmlElement(required = true)
    @XmlSchemaType(name = "dateTime")
    protected XMLGregorianCalendar beschikbaarTot;
    @XmlElement(name = "BestandKenmerken", namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstresultaat/kenmerken/v20170401")
    protected BestandKenmerkenType bestandKenmerken;
    @XmlElement(name = "digikoppeling-external-datareferences", namespace = "http://www.logius.nl/digikoppeling/gb/2010/10", required = true)
    protected ExternalDataReference digikoppelingExternalDatareferences;

    /**
     * Gets the value of the afgifteID property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAfgifteID() {
        return afgifteID;
    }

    /**
     * Sets the value of the afgifteID property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAfgifteID(String value) {
        this.afgifteID = value;
    }

    /**
     * Gets the value of the klantAfgiftenummer property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getKlantAfgiftenummer() {
        return klantAfgiftenummer;
    }

    /**
     * Sets the value of the klantAfgiftenummer property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setKlantAfgiftenummer(BigInteger value) {
        this.klantAfgiftenummer = value;
    }

    /**
     * Gets the value of the afgiftereferentie property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAfgiftereferentie() {
        return afgiftereferentie;
    }

    /**
     * Sets the value of the afgiftereferentie property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAfgiftereferentie(String value) {
        this.afgiftereferentie = value;
    }

    /**
     * Gets the value of the contractAfgiftenummer property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getContractAfgiftenummer() {
        return contractAfgiftenummer;
    }

    /**
     * Sets the value of the contractAfgiftenummer property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setContractAfgiftenummer(BigInteger value) {
        this.contractAfgiftenummer = value;
    }

    /**
     * Gets the value of the bestand property.
     * 
     * @return
     *     possible object is
     *     {@link Bestand }
     *     
     */
    public Bestand getBestand() {
        return bestand;
    }

    /**
     * Sets the value of the bestand property.
     * 
     * @param value
     *     allowed object is
     *     {@link Bestand }
     *     
     */
    public void setBestand(Bestand value) {
        this.bestand = value;
    }

    /**
     * Gets the value of the beschikbaarTot property.
     * 
     * @return
     *     possible object is
     *     {@link XMLGregorianCalendar }
     *     
     */
    public XMLGregorianCalendar getBeschikbaarTot() {
        return beschikbaarTot;
    }

    /**
     * Sets the value of the beschikbaarTot property.
     * 
     * @param value
     *     allowed object is
     *     {@link XMLGregorianCalendar }
     *     
     */
    public void setBeschikbaarTot(XMLGregorianCalendar value) {
        this.beschikbaarTot = value;
    }

    /**
     * Gets the value of the bestandKenmerken property.
     * 
     * @return
     *     possible object is
     *     {@link BestandKenmerkenType }
     *     
     */
    public BestandKenmerkenType getBestandKenmerken() {
        return bestandKenmerken;
    }

    /**
     * Sets the value of the bestandKenmerken property.
     * 
     * @param value
     *     allowed object is
     *     {@link BestandKenmerkenType }
     *     
     */
    public void setBestandKenmerken(BestandKenmerkenType value) {
        this.bestandKenmerken = value;
    }

    /**
     * Gets the value of the digikoppelingExternalDatareferences property.
     * 
     * @return
     *     possible object is
     *     {@link ExternalDataReference }
     *     
     */
    public ExternalDataReference getDigikoppelingExternalDatareferences() {
        return digikoppelingExternalDatareferences;
    }

    /**
     * Sets the value of the digikoppelingExternalDatareferences property.
     * 
     * @param value
     *     allowed object is
     *     {@link ExternalDataReference }
     *     
     */
    public void setDigikoppelingExternalDatareferences(ExternalDataReference value) {
        this.digikoppelingExternalDatareferences = value;
    }

}
